@@ -1159,6 +1159,43 @@ get_value_dependent_sm_edge_style <- function(value, theme){
 # ___________________  ----
 # 2. Measurement Model ----------------------
 
+
+
+#' Tests whether the i_th construct is endogenous or not
+#'
+#' @param model the model object
+#' @param index the index of the construct to test
+#'
+#' @return whether the construct is endogenous or not
+#' @export
+is_sink <- function(model, index) {
+  # get the mm_coding
+  mm_coding <- extract_mm_coding(model)
+
+
+  # Code explanation
+  # as the lower order constructs are not part of the structural model,
+  # we cannot extract their coding directly
+
+  # where does the indexed construct appear as a measurement?
+  idx <- model$mmMatrix[,2] == mm_coding[index, 1]
+  #get that construct's type
+  index_type <- model$mmMatrix[idx,3]
+  # is it a HOC?
+  is_higher_order_measurement <- startsWith(index_type, "HOC")
+
+  if(any(is_higher_order_measurement)) {
+    # cannot be sink
+    return(FALSE)
+  }
+
+  # otherwise test if it never appears in source
+  issink <- !any(mm_coding[index, ] %in% model$smMatrix[,1])
+
+  return(issink)
+}
+
+
 #' Generates the dot code for the measurement model
 #'
 #' @param model the model to use
@@ -1210,7 +1247,8 @@ dot_subcomponent_mm <- function(index, model, theme) {
   #}
 
   construct_type <- get_construct_type(model, mm_coding[index, 1])
-  edge_style <- get_mm_edge_style(theme, construct_type)
+  flip <- is_sink(model, index)
+  edge_style <- get_mm_edge_style(theme, construct_type, flip)
 
   nodes <- extract_mm_nodes(index, model, theme)
   edges <- extract_mm_edges(index, model, theme)
@@ -1325,7 +1363,8 @@ get_mm_node_shape <- function(model, construct, theme) {
 #'
 #' @param theme the theme to use
 #' @param construct_type Forward direction?
-get_mm_edge_style <- function(theme, construct_type){
+#' @param flip invert the arrow direction because of sink?
+get_mm_edge_style <- function(theme, construct_type, flip = FALSE){
 
   # read direction for matching construct type from theme
   if (construct_type == "C") {
@@ -1338,6 +1377,16 @@ get_mm_edge_style <- function(theme, construct_type){
     direction <- theme$construct.compositeB.arrow
   }
 
+  # flip the direction if sink
+  if(flip){
+    if(direction == "forward") {
+      direction <- "backward"
+    }
+    if(direction == "backward") {
+      direction <- "forward"
+    }
+  }
+
   # generate arrows from direction
   if (direction == "forward") {
     arrowhead <- "normal"
@@ -1536,13 +1585,22 @@ extract_mm_edges <- function(index, model, theme, weights = 1000) {
     edge_style <-
       get_value_dependent_mm_edge_style(loading, theme)
 
+    if(is_sink(model,index)) {
+      source_node <- mm_matrix_subset[i, 1]
+      target_node <- mm_matrix_subset[i, 2]
+    } else {
+      # TODO flip edges
+      source_node <- mm_matrix_subset[i, 2]
+      target_node <- mm_matrix_subset[i, 1]
+    }
+
     # append edge
     edges <- paste0(
       edges,
       "\"",
-      mm_matrix_subset[i, 2],
+      source_node,
       "\" -> {\"",
-      mm_matrix_subset[i, 1],
+      target_node,
       "\"}",
       "[weight = ",
       weights,
